@@ -2,7 +2,7 @@
 Module to add csv support
 """
 from functools import wraps
-from typing import TYPE_CHECKING, Any, Dict, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, Literal, Optional, Union
 
 import pandas as pd
 
@@ -20,32 +20,40 @@ def read_csv(
     preview_offset: int = 0,
     preview_nrows: Optional[int] = None,
     # change of default values
-    error_bad_lines: bool = False,  # pandas default: `True`
+    on_bad_lines: Literal["error", "warn", "skip"] = "skip",  # pandas default: "error"
+    encoding_errors: Literal["strict", "ignore"] = "ignore",  # pandas default: "strict"
     **kwargs: Any,
 ) -> pd.DataFrame:
     """
     The read_csv method is able to make a preview by reading on chunks
     """
     if preview_nrows is not None or preview_offset:
+        if (skipfooter := kwargs.pop("skipfooter", None)) is None:
+            skipfooter = 0
 
         # In case we don't have the native nrows given in kwargs, we're going
         # to use the provided preview_nrows
-        if (nrows := kwargs.get("nrows")) is None:
+        # and skipfooter should be equal to 0 because of this:
+        # cf : https://github.com/pandas-dev/pandas/blob/31c553f1e599e2695a33236e02511c2841ac9aa0/pandas/io/parsers/readers.py#L2209
+        if (nrows := kwargs.pop("nrows", None)) is None and skipfooter == 0:
             nrows = preview_nrows
 
         # In case we don't have the native skiprows given in kwargs,
         # we're going to use the provided preview_offset as range(1, preview_offset + 1)
-        if (skiprows := kwargs.get("skiprows")) is None:
+        if (skiprows := kwargs.pop("skiprows", None)) is None:
             skiprows = range(1, preview_offset + 1)
 
+        # keep the first row 0 (as the header) and then skip everything else up to row `preview_offset`
+        all_kwargs = {"skiprows": skiprows, "skipfooter": skipfooter, "nrows": nrows}
+        all_kwargs.update(kwargs)
+
         chunks = pd.read_csv(
             filepath_or_buffer,
-            error_bad_lines=error_bad_lines,
-            **kwargs,
-            # keep the first row 0 (as the header) and then skip everything else up to row `preview_offset`
-            skiprows=skiprows,
-            nrows=nrows,
+            on_bad_lines=on_bad_lines,
+            encoding_errors=encoding_errors,
+            **all_kwargs,
         )
+
         # if the chunksize is not in kwargs, we want to return the iterator
         if kwargs.get("chunksize") is None:
             return next(chunks) if not isinstance(chunks, pd.DataFrame) else chunks
@@ -53,21 +61,28 @@ def read_csv(
 
     return pd.read_csv(
         filepath_or_buffer,
-        error_bad_lines=error_bad_lines,
+        on_bad_lines=on_bad_lines,
+        encoding_errors=encoding_errors,
         **kwargs,
     )
 
 
-def _line_count(filepath_or_buffer: "FilePathOrBuffer") -> int:
-    with open(filepath_or_buffer) as f:
+def _line_count(filepath_or_buffer: "FilePathOrBuffer", encoding: Optional[str]) -> int:
+    with open(filepath_or_buffer, encoding=encoding) as f:
         lines = 0
         buf_size = 1024 * 1024
         read_f = f.read  # loop optimization
 
-        buf = read_f(buf_size)
-        while buf:
-            lines += buf.count("\n")
+        trailing_newline: bool = False
+        while True:
             buf = read_f(buf_size)
+            lines += buf.count("\n")
+            if not buf:
+                break
+            trailing_newline = buf.endswith("\n")
+
+        if not trailing_newline:
+            lines += 1
 
         return lines
 
@@ -75,7 +90,10 @@ def _line_count(filepath_or_buffer: "FilePathOrBuffer") -> int:
 def csv_meta(
     filepath_or_buffer: "FilePathOrBuffer", reader_kwargs: Dict[str, Any]
 ) -> Dict[str, Any]:
-    total_rows = _line_count(filepath_or_buffer)
+    total_rows = _line_count(filepath_or_buffer, reader_kwargs.get("encoding"))
+
+    if "names" not in reader_kwargs and total_rows > 0:  # No header row
+        total_rows = total_rows - 1
 
     if "nrows" in reader_kwargs:
         return {
